/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useEffect, useState} from 'react'
import styled from 'styled-components'
import axios from 'axios'
import {apiUrl, apiDomain} from '../env';
import Grid from '@material-ui/core/Grid';
import TextoObjeto from '../Components/ResourcePageComponents/TextoObjeto.js'
import Footer from '../Components/ResourcePageComponents/Footer.js'
import Sobre from '../Components/ResourcePageComponents/Sobre.js'
import noAvatar from "../img/default_profile.png";

export default function LearningObjectPage (props){
    const id = props.match.params.recursoId

    const [carregando, toggle] = useState(true)
    const [recurso, setRecurso] = useState({})
    useEffect( () => {
        axios.get( (`${apiUrl}/learning_objects/` + id )
    ).then( (response) => {
        console.log(response)
        setRecurso(response.data)
        toggle(false)
    }, (error) => {console.log(error)})
    }, [])

    return (
        <Background>
            {
                carregando ?
                (
                    <span>carregando</span>
                )
                :
                (
                    [
                        <Grid container spacing={2}>
                            <Grid item xs={12}>
                                <Card>
                                    <div>
                                    {recurso.thumbnail &&
                                        <img src={apiDomain + recurso.thumbnail}/>
                                    }

                                    {/*adicionar opcoes caso o usuario seja o publisher*/}
                                    <TextoObjeto
                                        name={recurso.name}
                                        rating={recurso.rating}
                                        likesCount={recurso.likes_count}
                                        likedBool={recurso.liked}
                                        objType={recurso.object_type}
                                        subjects={recurso.subjects}
                                        educationalStages={recurso.educational_stages}
                                        viewCount={recurso.views_count}
                                        downloadCount={recurso.downloads_count}
                                        />
                                    </div>
                                    {/*adicionar funcionalidade nos botoes do footer*/}
                                    <Footer/>
                                </Card>
                            </Grid>

                            <Grid item xs={12}>
                                <Card>
                                    {/*add option to MoreVertIcon*/}
                                    <Sobre
                                        avatar={recurso.publisher.avatar ? (apiDomain + recurso.publisher.avatar) : noAvatar}
                                        publisher={recurso.publisher.name}
                                        id={recurso.publisher.id}
                                        description={recurso.description}
                                        author={recurso.author}
                                        tags={recurso.tags}
                                        attachments={recurso.attachments}
                                        language={recurso.language}
                                        mimeType={recurso.default_mime_type}
                                        createdAt={recurso.created_at}
                                        updatedAt={recurso.updated_at}
                                        license={recurso.license}
                                        />
                                </Card>
                            </Grid>
                        </Grid>
                    ]
                )
            }

        </Background>
    )
}

const Background = styled.div`
    background-color : #f4f4f4;
    color : #666;
    font-family : 'Roboto', sans serif;
    padding-top : 30px;
`

const Card = styled.div`
    background-color : #fff;
    box-shadow : 0 1px 3px rgba(0,0,0,.12),0 1px 2px rgba(0,0,0,.24);
    margin-bottom : 30px;
    margin-right : auto;
    margin-left : auto;
    display : flex;
    flex-direction : column;
    @media screen and (min-width: 1200px) {
        width : 1170px;
    }
    @media screen and (min-width: 992px) and (max-width : 1199px){
        width : 970px;
    }
    @media screen and (min-width: 768px) and (max-width : 991px) {
        width : 750px;
    }

    img {
        background-color : #e5e5e5;
        height : 270px;
        width : 400px;
        float : left;
        padding : 0;
        object-fit : cover;
        @media screen and (max-width: 768px) {
            height : auto;
            width : 100%;
        }
    }
`
